@@ -44,7 +44,7 @@
 #define CRASHREPORT_HELPER "/usr/share/apport/apport-checkreports"
 #define CRASHREPORT_REPORT_APP "/usr/share/apport/apport-gtk"
 #define CRASHREPORT_DIR "/var/crash/"
-#define UNICAST_LOCAL_AVAHI_FILE "/var/run/avahi-daemon/disabled-for-unicast-local"
+#define UNICAST_LOCAL_AVAHI_FILE "/run/avahi-daemon/disabled-for-unicast-local"
 
 // security update autolaunch minimal time (12h)
 #define AUTOLAUNCH_MINIMAL_SECURITY_INTERVAL 12*60*60
