@@ -456,7 +456,7 @@ newest_log_file_timestamp(void)
       }
       for(j=0;j < pglob.gl_pathc; j++) {
 	 const char *log = pglob.gl_pathv[j];
-	 time_t mtime, bctime;
+	 time_t mtime;
 	 gchar *timestamp;
 
 	 if(g_stat(log, &buf) <0) {
@@ -473,12 +473,7 @@ newest_log_file_timestamp(void)
 	 g_debug_update ("mtime from %s: %i (%s)", log, mtime, timestamp);
 	 g_free (timestamp);
 
-	 bctime = buf.st_ctime;
-	 timestamp = readable_timestamp (bctime);
-	 g_debug_update ("ctime from %s: %i (%s)", log, bctime, timestamp);
-	 g_free (timestamp);
-
-	 newest_log_stamp = MAX(MAX(mtime, bctime), newest_log_stamp);
+	 newest_log_stamp = MAX(mtime, newest_log_stamp);
 	 timestamp = readable_timestamp (newest_log_stamp);
 	 g_debug_update ("last_launch from %s: %i (%s)", log, newest_log_stamp, timestamp);
 	 g_free (timestamp);
@@ -617,7 +612,7 @@ update_check (TrayApplet *ta)
    
    g_debug_update("%s returned %i (security: %i)", UPGRADE_CHECKER, priv->num_upgrades, priv->num_security);
 
-   if (stat("/var/run/reboot-required", &buf) == 0) {
+   if (stat("/run/reboot-required", &buf) == 0) {
       priv->reboot_pending = TRUE;
       g_debug_update("A reboot is currently pending.");
    }
